@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -80,7 +80,7 @@ __all__ = ("NetworkManagerClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -98,7 +98,7 @@ class Exceptions:
 
 class NetworkManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html)
     """
 
@@ -116,7 +116,7 @@ class NetworkManagerClient(BaseClient):
         """
         Associates a customer gateway with a device and optionally, with a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_customer_gateway)
         """
 
@@ -126,7 +126,7 @@ class NetworkManagerClient(BaseClient):
         """
         Associates a link to a device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_link)
         """
 
@@ -142,7 +142,7 @@ class NetworkManagerClient(BaseClient):
         Associates a transit gateway Connect peer with a device, and optionally, with a
         link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_transit_gateway_connect_peer)
         """
 
@@ -150,7 +150,7 @@ class NetworkManagerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#can_paginate)
         """
 
@@ -163,12 +163,12 @@ class NetworkManagerClient(BaseClient):
         LinkId: str = None,
         ConnectedLinkId: str = None,
         Description: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateConnectionResponseTypeDef:
         """
         Creates a connection between two devices.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_connection)
         """
 
@@ -184,22 +184,22 @@ class NetworkManagerClient(BaseClient):
         SerialNumber: str = None,
         Location: "LocationTypeDef" = None,
         SiteId: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateDeviceResponseTypeDef:
         """
         Creates a new device in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_device)
         """
 
     def create_global_network(
-        self, *, Description: str = None, Tags: List["TagTypeDef"] = None
+        self, *, Description: str = None, Tags: Sequence["TagTypeDef"] = None
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
         Creates a new, empty global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_global_network)
         """
 
@@ -212,12 +212,12 @@ class NetworkManagerClient(BaseClient):
         Description: str = None,
         Type: str = None,
         Provider: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateLinkResponseTypeDef:
         """
         Creates a new link for a specified site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_link)
         """
 
@@ -227,12 +227,12 @@ class NetworkManagerClient(BaseClient):
         GlobalNetworkId: str,
         Description: str = None,
         Location: "LocationTypeDef" = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateSiteResponseTypeDef:
         """
         Creates a new site in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_site)
         """
 
@@ -242,7 +242,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes the specified connection in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_connection)
         """
 
@@ -250,7 +250,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_device)
         """
 
@@ -258,7 +258,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_global_network)
         """
 
@@ -266,7 +266,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_link)
         """
 
@@ -274,7 +274,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_site)
         """
 
@@ -284,17 +284,21 @@ class NetworkManagerClient(BaseClient):
         """
         Deregisters a transit gateway from your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#deregister_transit_gateway)
         """
 
     def describe_global_networks(
-        self, *, GlobalNetworkIds: List[str] = None, MaxResults: int = None, NextToken: str = None
+        self,
+        *,
+        GlobalNetworkIds: Sequence[str] = None,
+        MaxResults: int = None,
+        NextToken: str = None
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
         Describes one or more global networks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#describe_global_networks)
         """
 
@@ -304,7 +308,7 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates a customer gateway from a device and a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_customer_gateway)
         """
 
@@ -314,7 +318,7 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates an existing device from a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_link)
         """
 
@@ -324,21 +328,21 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates a transit gateway Connect peer from a device and link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_transit_gateway_connect_peer)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#generate_presigned_url)
         """
 
@@ -346,7 +350,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        ConnectionIds: List[str] = None,
+        ConnectionIds: Sequence[str] = None,
         DeviceId: str = None,
         MaxResults: int = None,
         NextToken: str = None
@@ -354,7 +358,7 @@ class NetworkManagerClient(BaseClient):
         """
         Gets information about one or more of your connections in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_connections)
         """
 
@@ -362,7 +366,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        CustomerGatewayArns: List[str] = None,
+        CustomerGatewayArns: Sequence[str] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
@@ -370,7 +374,7 @@ class NetworkManagerClient(BaseClient):
         Gets the association information for customer gateways that are associated with
         devices and links in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_customer_gateway_associations)
         """
 
@@ -378,7 +382,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        DeviceIds: List[str] = None,
+        DeviceIds: Sequence[str] = None,
         SiteId: str = None,
         MaxResults: int = None,
         NextToken: str = None
@@ -386,7 +390,7 @@ class NetworkManagerClient(BaseClient):
         """
         Gets information about one or more of your devices in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_devices)
         """
 
@@ -402,7 +406,7 @@ class NetworkManagerClient(BaseClient):
         """
         Gets the link associations for a device or a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_link_associations)
         """
 
@@ -410,7 +414,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        LinkIds: List[str] = None,
+        LinkIds: Sequence[str] = None,
         SiteId: str = None,
         Type: str = None,
         Provider: str = None,
@@ -420,7 +424,7 @@ class NetworkManagerClient(BaseClient):
         """
         Gets information about one or more links in a specified global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_links)
         """
 
@@ -428,14 +432,14 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        SiteIds: List[str] = None,
+        SiteIds: Sequence[str] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> GetSitesResponseTypeDef:
         """
         Gets information about one or more of your sites in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_sites)
         """
 
@@ -443,7 +447,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayConnectPeerArns: List[str] = None,
+        TransitGatewayConnectPeerArns: Sequence[str] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> GetTransitGatewayConnectPeerAssociationsResponseTypeDef:
@@ -451,7 +455,7 @@ class NetworkManagerClient(BaseClient):
         Gets information about one or more of your transit gateway Connect peer
         associations in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_connect_peer_associations)
         """
 
@@ -459,7 +463,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayArns: List[str] = None,
+        TransitGatewayArns: Sequence[str] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
@@ -467,7 +471,7 @@ class NetworkManagerClient(BaseClient):
         Gets information about the transit gateway registrations in a specified global
         network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_registrations)
         """
 
@@ -475,7 +479,7 @@ class NetworkManagerClient(BaseClient):
         """
         Lists the tags for a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#list_tags_for_resource)
         """
 
@@ -485,23 +489,23 @@ class NetworkManagerClient(BaseClient):
         """
         Registers a transit gateway in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#register_transit_gateway)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Tags a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#untag_resource)
         """
 
@@ -517,7 +521,7 @@ class NetworkManagerClient(BaseClient):
         """
         Updates the information for an existing connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_connection)
         """
 
@@ -538,7 +542,7 @@ class NetworkManagerClient(BaseClient):
         """
         Updates the details for an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_device)
         """
 
@@ -548,7 +552,7 @@ class NetworkManagerClient(BaseClient):
         """
         Updates an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_global_network)
         """
 
@@ -565,7 +569,7 @@ class NetworkManagerClient(BaseClient):
         """
         Updates the details for an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_link)
         """
 
@@ -580,7 +584,7 @@ class NetworkManagerClient(BaseClient):
         """
         Updates the information for an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_site)
         """
 
@@ -589,14 +593,14 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
@@ -605,14 +609,14 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
@@ -621,21 +625,21 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
@@ -644,7 +648,7 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
@@ -653,6 +657,6 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
