@@ -34,7 +34,7 @@ Usage::
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -77,22 +77,25 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeGlobalNetworksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
     """
 
     def paginate(
-        self, *, GlobalNetworkIds: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
+        self,
+        *,
+        GlobalNetworkIds: Sequence[str] = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeGlobalNetworksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
 
 class GetConnectionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
     """
 
@@ -100,19 +103,19 @@ class GetConnectionsPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        ConnectionIds: List[str] = None,
+        ConnectionIds: Sequence[str] = None,
         DeviceId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetConnectionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
 
 class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
     """
 
@@ -120,18 +123,18 @@ class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        CustomerGatewayArns: List[str] = None,
+        CustomerGatewayArns: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetCustomerGatewayAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
 
 class GetDevicesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
     """
 
@@ -139,19 +142,19 @@ class GetDevicesPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        DeviceIds: List[str] = None,
+        DeviceIds: Sequence[str] = None,
         SiteId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetDevicesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
 
 class GetLinkAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
     """
 
@@ -164,14 +167,14 @@ class GetLinkAssociationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetLinkAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
 
 class GetLinksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
     """
 
@@ -179,21 +182,21 @@ class GetLinksPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        LinkIds: List[str] = None,
+        LinkIds: Sequence[str] = None,
         SiteId: str = None,
         Type: str = None,
         Provider: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetLinksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
 
 class GetSitesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
     """
 
@@ -201,18 +204,18 @@ class GetSitesPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        SiteIds: List[str] = None,
+        SiteIds: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetSitesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
 
 class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
     """
 
@@ -220,18 +223,18 @@ class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayConnectPeerArns: List[str] = None,
+        TransitGatewayConnectPeerArns: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetTransitGatewayConnectPeerAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
 
 class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
     """
 
@@ -239,10 +242,10 @@ class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayArns: List[str] = None,
+        TransitGatewayArns: Sequence[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[GetTransitGatewayRegistrationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
